package sun.management;

import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ArrayList;
import java.util.List;
import com.sun.management.VMOption;

class Flag
{
    private String name;
    private Object value;
    private VMOption.Origin origin;
    private boolean writeable;
    private boolean external;
    
    Flag(String name, Object o, boolean writeable, boolean external, VMOption.Origin origin) {
        this.name = name;
        this.value = ((o == null) ? "" : o);
        this.origin = origin;
        this.writeable = writeable;
        this.external = external;
    }
    
    Object getValue() {
        return this.value;
    }
    
    boolean isWriteable() {
        return this.writeable;
    }
    
    boolean isExternal() {
        return this.external;
    }
    
    VMOption getVMOption() {
        return new VMOption(this.name, this.value.toString(), this.writeable, this.origin);
    }
    
    static Flag getFlag(String s) {
        List<Flag> flags = getFlags(new String[] { s }, 1);
        if (flags.isEmpty()) {
            return null;
        }
        return (Flag)flags.get(0);
    }
    
    static List<Flag> getAllFlags() {
        return getFlags(null, getInternalFlagCount());
    }
    
    private static List<Flag> getFlags(String[] array, int n) {
        Flag[] array2 = new Flag[n];
        getFlags(array, array2, n);
        ArrayList<Flag> list = new ArrayList();
        for (Flag flag : array2) {
            if (flag != null) {
                list.add(flag);
            }
        }
        return list;
    }
    
    private static native String[] getAllFlagNames();
    
    private static native int getFlags(String[] p0, Flag[] p1, int p2);
    
    private static native int getInternalFlagCount();
    
    static synchronized native void setLongValue(String p0, long p1);
    
    static synchronized native void setBooleanValue(String p0, boolean p1);
    
    static synchronized native void setStringValue(String p0, String p1);
    
    private static native void initialize();
    
    static {
        AccessController.doPrivileged(new PrivilegedAction<Void>() {
            @Override
            public Void run() {
                System.loadLibrary("management");
                return null;
            }
        });
        initialize();
    }
}
